@@ -303,9 +303,12 @@ static int __file_invalidate_cache(struct thread_data *td, struct fio_file *f,
 	/*
 	 * FIXME: add blockdev flushing too
 	 */
-	if (f->mmap_ptr)
+	if (f->mmap_ptr) {
 		ret = madvise(f->mmap_ptr, f->mmap_sz, MADV_DONTNEED);
-	else if (f->filetype == FIO_TYPE_FILE) {
+#ifdef FIO_MADV_FREE
+		(void) madvise(f->mmap_ptr, f->mmap_sz, FIO_MADV_FREE);
+#endif
+	} else if (f->filetype == FIO_TYPE_FILE) {
 		ret = fadvise(f->fd, off, len, POSIX_FADV_DONTNEED);
 	} else if (f->filetype == FIO_TYPE_BD) {
 		ret = blockdev_invalidate_cache(f->fd);
@@ -611,7 +614,7 @@ int setup_files(struct thread_data *td)
 		temp_stall_ts = 1;
 		if (!terse_output)
 			log_info("%s: Laying out IO file(s) (%u file(s) /"
-				 " %LuMiB)\n", td->o.name, need_extend,
+				 " %LuMB)\n", td->o.name, need_extend,
 					extend_size >> 20);
 
 		for_each_file(td, f, i) {
